@@ -4,7 +4,7 @@ use strict;
 use YAML qw(LoadFile Load);
 use IO::File;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =head1 NAME
 
@@ -283,13 +283,17 @@ sub new
     my $config_hide_empty_sections = $args->{hide_empty_sections};
     $config_hide_empty_sections = $spec->{config}{hide_empty_sections}
         if $spec->{config} and exists($spec->{config}{hide_empty_sections});
-    
+
+    my $auto_configure = $args->{auto_configure};
+    $auto_configure = $spec->{config}{auto_configure}
+        if $spec->{config} and exists($spec->{config}{auto_configure});
 
     my $self = {
         spec                => $spec,
         debug               => $args->{debug},
         terminator          => $config_terminator || $args->{terminator} || '~',
         separator           => $config_separator  || $args->{separator}  || '*',
+        auto_configure      => $auto_configure,
         error               => '',
         new_lines           => $args->{new_lines},
         truncate_null       => $config_truncate_null       || 0,
@@ -313,6 +317,14 @@ sub read_record
 
     my $record = { };
 
+    if ($self->{auto_configure})
+    {
+        my $term_info = $self->_get_autoconfigure_info({ string => $string });
+
+        $self->{terminator} = $term_info->{terminator};
+        $self->{separator}  = $term_info->{separator};
+    }
+
     # strip newlines if applicable
     $string =~ s/[\r\n]//g
         unless $self->{terminator} =~ /[\r\n]/;
@@ -386,6 +398,22 @@ sub _parse_definition
     return $record;
 }
 
+
+sub _get_autoconfigure_info
+{
+    my ($self, $params) = @_;
+
+    my $string         = "$params->{string}";
+    $string =~ s/^\s+//g;
+
+    my @isa_chars = split(//, $string);
+
+    return {
+        separator  => $isa_chars[3],
+        terminator => $isa_chars[105],
+    };
+}
+
 sub _parse_edi
 {
     my ($self, $params) = @_;
@@ -421,6 +449,7 @@ sub _parse_edi
                 segments   => $segments,
                 type       => $type,
             });
+
             $IN_ISA = 1;
 
             %LOOP_SEGMENTS = ();
